==> haskell-wai-websockets-3.0.1.2-88-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-websockets
version: 3.0.1.2
id: wai-websockets-3.0.1.2-K2DvMVHnxEVIy9AFubcYpq
key: wai-websockets-3.0.1.2-K2DvMVHnxEVIy9AFubcYpq
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.
category: Web, Yesod
abi: 3aaea786309fe31499ec27df6ac01b12
exposed: True
exposed-modules:
    Network.Wai.Handler.WebSockets
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-websockets-3.0.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-websockets-3.0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-websockets-3.0.1.2
hs-libraries: HSwai-websockets-3.0.1.2-K2DvMVHnxEVIy9AFubcYpq
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    http-types-0.12.3-BsfSThCiYntF94Mfs0JU92
    network-2.8.0.0-1M86biZqFSo3ZnJTr6WevT transformers-0.5.6.2
    wai-3.2.2.1-FDNwy6o9t7ZJaaGowNIQmS
    websockets-0.12.5.3-8dsQgPdqbZqAxH4sEywJRr
haddock-interfaces: /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock
haddock-html: /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-websockets-3.0.1.2-91-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-websockets
version: 3.0.1.2
id: wai-websockets-3.0.1.2-Hx3lhYoilleA3eDWvXhfpL
key: wai-websockets-3.0.1.2-Hx3lhYoilleA3eDWvXhfpL
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.
category: Web, Yesod
abi: d886e8db6db4584536ba2697f8e4f807
exposed: True
exposed-modules:
    Network.Wai.Handler.WebSockets
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-websockets-3.0.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-websockets-3.0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-websockets-3.0.1.2
hs-libraries: HSwai-websockets-3.0.1.2-Hx3lhYoilleA3eDWvXhfpL
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    http-types-0.12.3-HyLqeUOIbzSKBEUtzZNX61
    network-2.8.0.0-3PgnnHopFNTASnxFyU0kPh transformers-0.5.6.2
    wai-3.2.2.1-KD2whrykQYM5hV5ErkjpaS
    websockets-0.12.5.3-35e4c7bj26J5SRNWLXLSLJ
haddock-interfaces: /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock
haddock-html: /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
